@@ -81,3 +81,7 @@ LOG_SIZE_IN_BYTES = 1024 * 1024
 LOG_SIZE_TO_CLEAN = 10 * 1024
 
 DIFF_WITH_ALIAS = 0.5
+
+SHELL_LOGGER_SOCKET_ENV = 'SHELL_LOGGER_SOCKET'
+
+SHELL_LOGGER_LIMIT = 5
