@@ -1,13 +1,13 @@
 from difflib import get_close_matches
 from thefuck.utils import get_all_executables, \
-    get_valid_history_without_current, get_closest
+    get_valid_history_without_current, get_closest, which
 from thefuck.specific.sudo import sudo_support
 
 
 @sudo_support
 def match(command):
-    return (command.script_parts
-            and 'not found' in command.stderr
+    return (not which(command.script_parts[0])
+            and 'not found' in command.output
             and bool(get_close_matches(command.script_parts[0],
                                        get_all_executables())))
 
